==> aws-cdk.aws-ec2-1.100.0.tar.gz: package/lib/nat.d.ts <==
import { Connections, IConnectable } from './connections';
import { InstanceType } from './instance-types';
import { IMachineImage, LookupMachineImage } from './machine-image';
import { ISecurityGroup } from './security-group';
import { PrivateSubnet, PublicSubnet, Vpc } from './vpc';
/**
 * Direction of traffic to allow all by default.
 *
 * @stability stable
 */
export declare enum NatTrafficDirection {
    /**
     * Allow all outbound traffic and disallow all inbound traffic.
     *
     * @stability stable
     */
    OUTBOUND_ONLY = "OUTBOUND_ONLY",
    /**
     * Allow all outbound and inbound traffic.
     *
     * @stability stable
     */
    INBOUND_AND_OUTBOUND = "INBOUND_AND_OUTBOUND",
    /**
     * Disallow all outbound and inbound traffic.
     *
     * @stability stable
     */
    NONE = "NONE"
}
/**
 * Pair represents a gateway created by NAT Provider.
 *
 * @stability stable
 */
export interface GatewayConfig {
    /**
     * Availability Zone.
     *
     * @stability stable
     */
    readonly az: string;
    /**
     * Identity of gateway spawned by the provider.
     *
     * @stability stable
     */
    readonly gatewayId: string;
}
/**
 * (experimental) NAT providers.
 *
 * Determines what type of NAT provider to create, either NAT gateways or NAT
 * instance.
 *
 * @experimental
 */
export declare abstract class NatProvider {
    /**
     * (experimental) Use NAT Gateways to provide NAT services for your VPC.
     *
     * NAT gateways are managed by AWS.
     *
     * @see https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html
     * @experimental
     */
    static gateway(): NatProvider;
    /**
     * (experimental) Use NAT instances to provide NAT services for your VPC.
     *
     * NAT instances are managed by you, but in return allow more configuration.
     *
     * Be aware that instances created using this provider will not be
     * automatically replaced if they are stopped for any reason. You should implement
     * your own NatProvider based on AutoScaling groups if you need that.
     *
     * @see https://docs.aws.amazon.com/vpc/latest/userguide/VPC_NAT_Instance.html
     * @experimental
     */
    static instance(props: NatInstanceProps): NatInstanceProvider;
    /**
     * (experimental) Return list of gateways spawned by the provider.
     *
     * @experimental
     */
    abstract readonly configuredGateways: GatewayConfig[];
    /**
     * (experimental) Called by the VPC to configure NAT.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @experimental
     */
    abstract configureNat(options: ConfigureNatOptions): void;
    /**
     * (experimental) Configures subnet with the gateway.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @experimental
     */
    abstract configureSubnet(subnet: PrivateSubnet): void;
}
/**
 * (experimental) Options passed by the VPC when NAT needs to be configured.
 *
 * @experimental
 */
export interface ConfigureNatOptions {
    /**
     * (experimental) The VPC we're configuring NAT for.
     *
     * @experimental
     */
    readonly vpc: Vpc;
    /**
     * (experimental) The public subnets where the NAT providers need to be placed.
     *
     * @experimental
     */
    readonly natSubnets: PublicSubnet[];
    /**
     * (experimental) The private subnets that need to route through the NAT providers.
     *
     * There may be more private subnets than public subnets with NAT providers.
     *
     * @experimental
     */
    readonly privateSubnets: PrivateSubnet[];
}
/**
 * (experimental) Properties for a NAT instance.
 *
 * @experimental
 */
export interface NatInstanceProps {
    /**
     * (experimental) The machine image (AMI) to use.
     *
     * By default, will do an AMI lookup for the latest NAT instance image.
     *
     * If you have a specific AMI ID you want to use, pass a `GenericLinuxImage`. For example:
     *
     * ```ts
     * ec2.NatProvider.instance({
     *    instanceType: new ec2.InstanceType('t3.micro'),
     *    machineImage: new ec2.GenericLinuxImage({
     *      'us-east-2': 'ami-0f9c61b5a562a16af'
     *    })
     * })
     * ```
     *
     * @default - Latest NAT instance image
     * @experimental
     */
    readonly machineImage?: IMachineImage;
    /**
     * (experimental) Instance type of the NAT instance.
     *
     * @experimental
     */
    readonly instanceType: InstanceType;
    /**
     * (experimental) Name of SSH keypair to grant access to instance.
     *
     * @default - No SSH access will be possible.
     * @experimental
     */
    readonly keyName?: string;
    /**
     * (experimental) Security Group for NAT instances.
     *
     * @default - A new security group will be created
     * @experimental
     */
    readonly securityGroup?: ISecurityGroup;
    /**
     * (deprecated) Allow all inbound traffic through the NAT instance.
     *
     * If you set this to false, you must configure the NAT instance's security
     * groups in another way, either by passing in a fully configured Security
     * Group using the `securityGroup` property, or by configuring it using the
     * `.securityGroup` or `.connections` members after passing the NAT Instance
     * Provider to a Vpc.
     *
     * @default true
     * @deprecated - Use `defaultAllowedTraffic`.
     */
    readonly allowAllTraffic?: boolean;
    /**
     * (experimental) Direction to allow all traffic through the NAT instance by default.
     *
     * By default, inbound and outbound traffic is allowed.
     *
     * If you set this to another value than INBOUND_AND_OUTBOUND, you must
     * configure the NAT instance's security groups in another way, either by
     * passing in a fully configured Security Group using the `securityGroup`
     * property, or by configuring it using the `.securityGroup` or
     * `.connections` members after passing the NAT Instance Provider to a Vpc.
     *
     * @default NatTrafficDirection.INBOUND_AND_OUTBOUND
     * @experimental
     */
    readonly defaultAllowedTraffic?: NatTrafficDirection;
}
/**
 * NAT provider which uses NAT Instances.
 *
 * @stability stable
 */
export declare class NatInstanceProvider extends NatProvider implements IConnectable {
    private readonly props;
    private gateways;
    private _securityGroup?;
    private _connections?;
    /**
     * @stability stable
     */
    constructor(props: NatInstanceProps);
    /**
     * Called by the VPC to configure NAT.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @stability stable
     */
    configureNat(options: ConfigureNatOptions): void;
    /**
     * The Security Group associated with the NAT instances.
     *
     * @stability stable
     */
    get securityGroup(): ISecurityGroup;
    /**
     * Manage the Security Groups associated with the NAT instances.
     *
     * @stability stable
     */
    get connections(): Connections;
    /**
     * Return list of gateways spawned by the provider.
     *
     * @stability stable
     */
    get configuredGateways(): GatewayConfig[];
    /**
     * Configures subnet with the gateway.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @stability stable
     */
    configureSubnet(subnet: PrivateSubnet): void;
}
/**
 * (experimental) Machine image representing the latest NAT instance image.
 *
 * @experimental
 */
export declare class NatInstanceImage extends LookupMachineImage {
    /**
     * @experimental
     */
    constructor();
}

==> aws-cdk.aws-ec2-1.126.0.tar.gz: package/lib/nat.d.ts <==
import { Connections, IConnectable } from './connections';
import { InstanceType } from './instance-types';
import { IMachineImage, LookupMachineImage } from './machine-image';
import { ISecurityGroup } from './security-group';
import { PrivateSubnet, PublicSubnet, Vpc } from './vpc';
/**
 * Direction of traffic to allow all by default.
 *
 * @stability stable
 */
export declare enum NatTrafficDirection {
    /**
     * Allow all outbound traffic and disallow all inbound traffic.
     *
     * @stability stable
     */
    OUTBOUND_ONLY = "OUTBOUND_ONLY",
    /**
     * Allow all outbound and inbound traffic.
     *
     * @stability stable
     */
    INBOUND_AND_OUTBOUND = "INBOUND_AND_OUTBOUND",
    /**
     * Disallow all outbound and inbound traffic.
     *
     * @stability stable
     */
    NONE = "NONE"
}
/**
 * Pair represents a gateway created by NAT Provider.
 *
 * @stability stable
 */
export interface GatewayConfig {
    /**
     * Availability Zone.
     *
     * @stability stable
     */
    readonly az: string;
    /**
     * Identity of gateway spawned by the provider.
     *
     * @stability stable
     */
    readonly gatewayId: string;
}
/**
 * NAT providers.
 *
 * Determines what type of NAT provider to create, either NAT gateways or NAT
 * instance.
 *
 * @stability stable
 */
export declare abstract class NatProvider {
    /**
     * Use NAT Gateways to provide NAT services for your VPC.
     *
     * NAT gateways are managed by AWS.
     *
     * @see https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html
     * @stability stable
     */
    static gateway(props?: NatGatewayProps): NatProvider;
    /**
     * Use NAT instances to provide NAT services for your VPC.
     *
     * NAT instances are managed by you, but in return allow more configuration.
     *
     * Be aware that instances created using this provider will not be
     * automatically replaced if they are stopped for any reason. You should implement
     * your own NatProvider based on AutoScaling groups if you need that.
     *
     * @see https://docs.aws.amazon.com/vpc/latest/userguide/VPC_NAT_Instance.html
     * @stability stable
     */
    static instance(props: NatInstanceProps): NatInstanceProvider;
    /**
     * Return list of gateways spawned by the provider.
     *
     * @stability stable
     */
    abstract readonly configuredGateways: GatewayConfig[];
    /**
     * Called by the VPC to configure NAT.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @stability stable
     */
    abstract configureNat(options: ConfigureNatOptions): void;
    /**
     * Configures subnet with the gateway.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @stability stable
     */
    abstract configureSubnet(subnet: PrivateSubnet): void;
}
/**
 * Options passed by the VPC when NAT needs to be configured.
 *
 * @stability stable
 */
export interface ConfigureNatOptions {
    /**
     * The VPC we're configuring NAT for.
     *
     * @stability stable
     */
    readonly vpc: Vpc;
    /**
     * The public subnets where the NAT providers need to be placed.
     *
     * @stability stable
     */
    readonly natSubnets: PublicSubnet[];
    /**
     * The private subnets that need to route through the NAT providers.
     *
     * There may be more private subnets than public subnets with NAT providers.
     *
     * @stability stable
     */
    readonly privateSubnets: PrivateSubnet[];
}
/**
 * Properties for a NAT gateway.
 *
 * @stability stable
 */
export interface NatGatewayProps {
    /**
     * EIP allocation IDs for the NAT gateways.
     *
     * @default - No fixed EIPs allocated for the NAT gateways
     * @stability stable
     */
    readonly eipAllocationIds?: string[];
}
/**
 * Properties for a NAT instance.
 *
 * @stability stable
 */
export interface NatInstanceProps {
    /**
     * The machine image (AMI) to use.
     *
     * By default, will do an AMI lookup for the latest NAT instance image.
     *
     * If you have a specific AMI ID you want to use, pass a `GenericLinuxImage`. For example:
     *
     * ```ts
     * ec2.NatProvider.instance({
     *    instanceType: new ec2.InstanceType('t3.micro'),
     *    machineImage: new ec2.GenericLinuxImage({
     *      'us-east-2': 'ami-0f9c61b5a562a16af'
     *    })
     * })
     * ```
     *
     * @default - Latest NAT instance image
     * @stability stable
     */
    readonly machineImage?: IMachineImage;
    /**
     * Instance type of the NAT instance.
     *
     * @stability stable
     */
    readonly instanceType: InstanceType;
    /**
     * Name of SSH keypair to grant access to instance.
     *
     * @default - No SSH access will be possible.
     * @stability stable
     */
    readonly keyName?: string;
    /**
     * Security Group for NAT instances.
     *
     * @default - A new security group will be created
     * @stability stable
     */
    readonly securityGroup?: ISecurityGroup;
    /**
     * (deprecated) Allow all inbound traffic through the NAT instance.
     *
     * If you set this to false, you must configure the NAT instance's security
     * groups in another way, either by passing in a fully configured Security
     * Group using the `securityGroup` property, or by configuring it using the
     * `.securityGroup` or `.connections` members after passing the NAT Instance
     * Provider to a Vpc.
     *
     * @default true
     * @deprecated - Use `defaultAllowedTraffic`.
     */
    readonly allowAllTraffic?: boolean;
    /**
     * Direction to allow all traffic through the NAT instance by default.
     *
     * By default, inbound and outbound traffic is allowed.
     *
     * If you set this to another value than INBOUND_AND_OUTBOUND, you must
     * configure the NAT instance's security groups in another way, either by
     * passing in a fully configured Security Group using the `securityGroup`
     * property, or by configuring it using the `.securityGroup` or
     * `.connections` members after passing the NAT Instance Provider to a Vpc.
     *
     * @default NatTrafficDirection.INBOUND_AND_OUTBOUND
     * @stability stable
     */
    readonly defaultAllowedTraffic?: NatTrafficDirection;
}
/**
 * NAT provider which uses NAT Instances.
 *
 * @stability stable
 */
export declare class NatInstanceProvider extends NatProvider implements IConnectable {
    private readonly props;
    private gateways;
    private _securityGroup?;
    private _connections?;
    /**
     * @stability stable
     */
    constructor(props: NatInstanceProps);
    /**
     * Called by the VPC to configure NAT.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @stability stable
     */
    configureNat(options: ConfigureNatOptions): void;
    /**
     * The Security Group associated with the NAT instances.
     *
     * @stability stable
     */
    get securityGroup(): ISecurityGroup;
    /**
     * Manage the Security Groups associated with the NAT instances.
     *
     * @stability stable
     */
    get connections(): Connections;
    /**
     * Return list of gateways spawned by the provider.
     *
     * @stability stable
     */
    get configuredGateways(): GatewayConfig[];
    /**
     * Configures subnet with the gateway.
     *
     * Don't call this directly, the VPC will call it automatically.
     *
     * @stability stable
     */
    configureSubnet(subnet: PrivateSubnet): void;
}
/**
 * Machine image representing the latest NAT instance image.
 *
 * @stability stable
 */
export declare class NatInstanceImage extends LookupMachineImage {
    /**
     * @stability stable
     */
    constructor();
}
